### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Exchange class for the Zope 3 based ng.content.profile.excangeannotation package

$Id: exchange.py 51883 2008-10-20 19:14:59Z cray $
"""
__author__  = "Andrey Orlov, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51883 $"

from persistent import Persistent
from zope.interface import Interface, implements
from interfaces import IExchangeContainer, IMailboxData
from zope.app.container.ordered import OrderedContainer
from zope.app.container.contained import Contained
from zope.app.container.interfaces import IContained

class Exchange(OrderedContainer,Contained) :
    __doc__ = IExchangeContainer.__doc__
    implements(IExchangeContainer,IContained)
    __parent__ = None

    def __init__(self,*kv,**kw) :
        super(Exchange,self).__init__(*kv,**kw)
        
    def add(self,message) :
        try :
          num = int(self.keys()[-1])
        except (IndexError,TypeError,UnicodeEncodeError) :
          num = 1
        else :                    
          while "%06u" % num in self :
            num += 1
            
        title = "%06u" % num
        self.count += 1          
        self[title] = message
        message.__name__ = title
        message.__parent__ = self
        return message

    _count = 0

    def count_Set(self,value) :
        print "Set", value
        IMailboxData(self.__parent__).count += value - self._count
        self._count = value

    def count_Get(self) :
        return self._count
        
    count = property(count_Get,count_Set)
